@@ -1,6 +1,6 @@
 from django.utils.safestring import mark_safe
 
-from django_tables2.utils import Accessor, AttributeDict
+from django_tables2.utils import Accessor, AttributeDict, computed_values
 
 from .base import Column, library
 
@@ -65,8 +65,10 @@ class CheckBoxColumn(Column):
 
         general = self.attrs.get("input")
         specific = self.attrs.get("td__input")
-        attrs = AttributeDict(default, **(specific or general or {}))
-        return mark_safe("<input %s/>" % attrs.as_html())
+
+        attrs = dict(default, **(specific or general or {}))
+        attrs = computed_values(attrs, kwargs={"record": record, "value": value})
+        return mark_safe("<input %s/>" % AttributeDict(attrs).as_html())
 
     def is_checked(self, value, record):
         """
