@@ -1,14 +1,17 @@
 import json
 
 from django.utils.html import format_html
-from django.utils.text import capfirst
 
 from ..utils import AttributeDict
 from .base import library
 from .linkcolumn import BaseLinkColumn
 
 try:
-    from django.contrib.postgres.fields import HStoreField, JSONField
+    try:
+        from django.contrib.postgres.fields import HStoreField
+        from django.db.models import JSONField  # django==3.1 moved JSONField
+    except ImportError:
+        from django.contrib.postgres.fields import HStoreField, JSONField
 
     POSTGRES_AVAILABLE = True
 except ImportError:
@@ -55,7 +58,7 @@ class JSONColumn(BaseLinkColumn):
         )
 
     @classmethod
-    def from_field(cls, field):
+    def from_field(cls, field, **kwargs):
         if POSTGRES_AVAILABLE:
-            if isinstance(field, JSONField) or isinstance(field, HStoreField):
-                return cls(verbose_name=capfirst(field.verbose_name))
+            if isinstance(field, (JSONField, HStoreField)):
+                return cls(**kwargs)
