@@ -1,5 +1,4 @@
 from django.db import models
-from django.utils.text import capfirst
 
 from .base import library
 from .templatecolumn import TemplateColumn
@@ -11,10 +10,8 @@ class TimeColumn(TemplateColumn):
     A column that renders times in the local timezone.
 
     Arguments:
-        format (str): format string in same format as Django's ``time`` template
-            filter (optional)
-        short (bool): if *format* is not specified, use Django's ``TIME_FORMAT``
-            setting
+        format (str): format string in same format as Django's ``time`` template filter (optional).
+        short (bool): if *format* is not specified, use Django's ``TIME_FORMAT`` setting.
     """
 
     def __init__(self, format=None, *args, **kwargs):
@@ -24,6 +21,6 @@ class TimeColumn(TemplateColumn):
         super().__init__(template_code=template, *args, **kwargs)
 
     @classmethod
-    def from_field(cls, field):
+    def from_field(cls, field, **kwargs):
         if isinstance(field, models.TimeField):
-            return cls(verbose_name=capfirst(field.verbose_name))
+            return cls(**kwargs)
