@@ -1,5 +1,4 @@
-
 from .export import TableExport
 from .views import ExportMixin
 
-__all__ = ('TableExport', 'ExportMixin')
+__all__ = ("TableExport", "ExportMixin")
