@@ -175,11 +175,12 @@ class TableOptions:
             for key in keys:
                 value = getattr(options, key, None)
                 if value is not None and not isinstance(value, types):
-                    expression = f"{class_name}.{key} = {value.__repr__()}"
+                    expression = "{}.{} = {}".format(class_name, key, value.__repr__())
 
-                    allowed = ", ".join([t.__name__ for t in types])
                     raise TypeError(
-                        f"{expression} (type {type(value).__name__}), but type must be one of ({allowed})"
+                        "{} (type {}), but type must be one of ({})".format(
+                            expression, type(value).__name__, ", ".join([t.__name__ for t in types])
+                        )
                     )
 
 
@@ -279,7 +280,7 @@ class Table(metaclass=DeclarativeColumnsMetaclass):
         # note that although data is a keyword argument, it used to be positional
         # so it is assumed to be the first argument to this method.
         if data is None:
-            raise TypeError(f"Argument data to {type(self).__name__} is required")
+            raise TypeError("Argument data to {} is required".format(type(self).__name__))
 
         self.exclude = exclude or self._meta.exclude
         self.sequence = sequence
@@ -604,15 +605,15 @@ class Table(metaclass=DeclarativeColumnsMetaclass):
 
     @property
     def prefixed_order_by_field(self):
-        return f"{self.prefix}{self.order_by_field}"
+        return "%s%s" % (self.prefix, self.order_by_field)
 
     @property
     def prefixed_page_field(self):
-        return f"{self.prefix}{self.page_field}"
+        return "%s%s" % (self.prefix, self.page_field)
 
     @property
     def prefixed_per_page_field(self):
-        return f"{self.prefix}{self.per_page_field}"
+        return "%s%s" % (self.prefix, self.per_page_field)
 
     @property
     def sequence(self):
