@@ -74,10 +74,8 @@ class Group(models.Model):
 class Occupation(models.Model):
     name = models.CharField(max_length=200)
     region = models.ForeignKey("Region", null=True, on_delete=models.CASCADE)
-    boolean = models.NullBooleanField(null=True)
-    boolean_with_choices = models.NullBooleanField(
-        null=True, choices=((True, "Yes"), (False, "No"))
-    )
+    boolean = models.BooleanField(null=True)
+    boolean_with_choices = models.BooleanField(null=True, choices=((True, "Yes"), (False, "No")))
 
     def get_absolute_url(self):
         return reverse("occupation", args=(self.pk,))
