@@ -83,6 +83,12 @@ class ConfigTest(SimpleTestCase):
         table = SimpleTable([{}], request=request)
         self.assertTrue(table.columns["abc"].is_ordered)
 
+    def test_request_is_added_to_the_table(self):
+        table = self.table()
+        request = build_request("/")
+        RequestConfig(request, paginate=False).configure(table)
+        self.assertEqual(table.request, request)
+
 
 class NoPaginationQueriesTest(TestCase):
     def test_should_not_count_with_paginate_False(self):
