@@ -286,10 +286,23 @@ class TablePageRangeTest(SimpleTestCase):
             table_page_range(paginator.page(7), paginator), [1, "...", 4, 5, 6, 7, 8, 9, 10, 11]
         )
 
-    def test_table_page_range_lazy(self):
+    def test_table_page_range_lazy_beginning(self):
         paginator = LazyPaginator(range(1, 1000), 10)
 
         self.assertEqual(table_page_range(paginator.page(1), paginator), range(1, 3))
+
+    def test_table_page_range_lazy_middle(self):
+        paginator = LazyPaginator(range(1, 1000), 10)
+
         self.assertEqual(
-            table_page_range(paginator.page(10), paginator), [1, "...", 4, 5, 6, 7, 8, 9, 10, 11]
+            table_page_range(paginator.page(10), paginator),
+            [1, "...", 4, 5, 6, 7, 8, 9, 10, 11, "..."],
+        )
+
+    def test_table_page_range_lazy_last_page(self):
+        paginator = LazyPaginator(range(1, 1000), 10)
+
+        self.assertEqual(
+            table_page_range(paginator.page(100), paginator),
+            [1, "...", 93, 94, 95, 96, 97, 98, 99, 100],
         )
