@@ -72,6 +72,17 @@ class OrderByTest(TestCase):
         self.assertTrue(b.is_descending)
         self.assertFalse(b.is_ascending)
 
+    def test_error_on_legacy_separator(self):
+        message = "Use '__' to separate path components, not '.' in accessor 'a.b'"
+        with self.assertWarnsRegex(DeprecationWarning, message):
+            OrderBy("a.b")
+
+    def test_for_queryset(self):
+        ab = OrderBy("a.b")
+        self.assertEqual(ab.for_queryset(), "a__b")
+        ab = OrderBy("a__b")
+        self.assertEqual(ab.for_queryset(), "a__b")
+
 
 class AccessorTest(TestCase):
     def test_bare(self):
@@ -86,8 +97,12 @@ class AccessorTest(TestCase):
         self.assertEqual(Accessor("-2").resolve("Brad"), "a")
 
     def test_calling_methods(self):
-        self.assertEqual(Accessor("2.upper").resolve("Brad"), "A")
-        self.assertEqual(Accessor("2.upper.__len__").resolve("Brad"), 1)
+        self.assertEqual(Accessor("2__upper").resolve("Brad"), "A")
+
+    def test_error_on_legacy_separator(self):
+        message = "Use '__' to separate path components, not '.' in accessor '2.upper'"
+        with self.assertWarnsRegex(DeprecationWarning, message):
+            Accessor("2.upper")
 
     def test_honors_alters_data(self):
         class Foo:
@@ -108,8 +123,13 @@ class AccessorTest(TestCase):
 
     def test_penultimate(self):
         context = {"a": {"a": 1, "b": {"c": 2, "d": 4}}}
-        self.assertEqual(Accessor("a.b.c").penultimate(context), (context["a"]["b"], "c"))
-        self.assertEqual(Accessor("a.b.c.d.e").penultimate(context), (None, "e"))
+        self.assertEqual(Accessor("a__b__c").penultimate(context), (context["a"]["b"], "c"))
+        self.assertEqual(Accessor("a___b___c___d___e").penultimate(context), (None, "e"))
+
+    def test_short_circuit_dict(self):
+        context = {"occupation__name": "Carpenter"}
+
+        self.assertEqual(Accessor("occupation__name").resolve(context), "Carpenter")
 
 
 class AccessorTestModel(models.Model):
